@@ -5,8 +5,23 @@
 #include "perl.h"
 #define NO_XSLOCKS
 #include "XSUB.h"
+#define NEED_newRV_noinc
+#define NEED_newSVpvn_flags
+#define NEED_sv_2pv_flags_GLOBAL
 #include "ppport.h"
 #include <stdint.h>
+#include <sys/stat.h>
+#include <fcntl.h>
+#include <stdio.h>
+#include <stdlib.h>
+#include <string.h>
+#include <errno.h>
+#ifdef WIN32
+#include <windows.h>
+#include <io.h>
+#else
+#include <sys/mman.h>
+#endif
 
 #ifndef MUTABLE_PTR
 #if defined(__GNUC__) && !defined(PERL_GCC_BRACE_GROUPS_FORBIDDEN)
@@ -34,6 +49,10 @@
 typedef uintptr_t xh_bool_t;
 typedef uintptr_t xh_uint_t;
 typedef intptr_t  xh_int_t;
+typedef u_char    xh_char_t;
+
+#define XH_CHAR_CAST    (xh_char_t *)
+#define XH_EMPTY_STRING (XH_CHAR_CAST "")
 
 #if defined(XH_HAVE_ICONV) || defined(XH_HAVE_ICU)
 #define XH_HAVE_ENCODER
@@ -43,4 +62,10 @@ typedef intptr_t  xh_int_t;
 #define XH_HAVE_DOM
 #endif
 
+#ifdef XH_HAVE_DOM
+#include <libxml/parser.h>
+#endif
+
+#define XH_HAVE_MMAP
+
 #endif /* _XH_CONFIG_H_ */
